Class: Btape::LLM::Error
- Inherits:
-
Error
- Object
- Error
- Btape::LLM::Error
- Defined in:
- lib/btape/llm/client.rb
Overview
Raised when the model, or the server in front of it, could not answer.
Raised when the model, or the server in front of it, could not answer.